class SharksAhead::CLI

  def call
    welcome
  end

  def welcome
    puts "\e[H\e[2J"
    # text art generator at http://fsymbols.com/generators/carty/
    puts <<-DOC
                    ╔═══╗ ╔╗ ╔╗ ╔═══╗ ╔═══╗ ╔╗╔═╗ ╔╗
                    ║╔═╗║ ║║ ║║ ║╔═╗║ ║╔═╗║ ║║║╔╝ ║║
                    ║╚══╗ ║╚═╝║ ║║ ║║ ║╚═╝║ ║╚╝╝  ║║
                    ╚══╗║ ║╔═╗║ ║╚═╝║ ║╔╗╔╝ ║╔╗║  ╚╝
                    ║╚═╝║ ║║ ║║ ║╔═╗║ ║║║╚╗ ║║║╚╗ ╔╗
                    ╚═══╝ ╚╝ ╚╝ ╚╝ ╚╝ ╚╝╚═╝ ╚╝╚═╝ ╚╝
    DOC

    # ascii ship art from http://chris.com/ascii/index.php?art=transportation/nautical
    puts "               _~"
    puts "            _~ )_)_~ "
    puts "            )_))_))_)    Thar be sharks ahead! "
    puts "            _!__!__!_"
    puts "       ~  ~ \\______t/"
    puts "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~|\\~~~~~~~|\\~~~~~~~~~~~~~~~~"
    print "\nAre ye prepared to look fer 'em? Tell me! Yes or no?  "

    answer_look
  end

  def answer_look
    answer = nil
    while answer != "exit"
      answer = gets.chomp
      case answer
      when /^(y|yes)$/i then answer_yes
      when /^(n|no)$/i  then goodbye1
      else belay_that
      end
    end
  end

  def answer_yes
    puts "\e[H\e[2J"
    # ascii shark art from http://www.ascii-art.de/ascii/s/sharks.txt
    puts  "     ,   "
    puts  "     .'; "
    puts  "   .-'` .' "
    puts  "   ,`.-'-.`\ "
    puts  "   ; /     '-'"
    puts  "   | \       ,-,"
    puts  "   \  '-.__   )_`'._ "
    puts  "   '.     ```      ``'--._ "
    puts  "   .-' ,                   `'-.   Are ye lookin' fer dead sharks"
    puts  "   '-'`-._           ((   o   )   or livin'? Tell me!"
    puts  "         `'--....(`- ,__..--' "
    print "                '-'`              Dead or alive?  "

    answer_dead_or_alive
  end

  def answer_dead_or_alive
    answer = nil
    while answer != "exit"
      answer = gets.chomp
      case answer
      when /^(d|dead)$/i  then list_extinct
      when /^(a|alive)$/i then list_living
      when /^(e|exit)$/i  then goodbye2
      else belay_that
      end
    end
  end

  def list_extinct
    puts "\nWe'll be lookin' fer extinct ones. Here y'arr:\n\n"

    @shark_extinct = SharksAhead::SharkExtinct.get_extinct_sharks
    @shark_extinct.each.with_index(1) do |shark, i|
      printf "%3s  -  %-50s\n", i, shark[:name]
    end
    description_extinct
  end

  def description_extinct
    extinct_input = nil
    while extinct_input != "exit"
      give_choices

      extinct_input = gets.chomp
      the_shark = @shark_extinct[extinct_input.to_i-1]

      case extinct_input
      when /([1-8])/ then puts word_wrap("\n#{the_shark[:description]}\n\n", 75)
      when /^(l|list)$/i   then list_extinct
      when /^(e|exit)$/i   then goodbye2
      when /^(s|start)$/i  then welcome
      else belay_that
      end
    end
  end

  def list_living
    puts "\nLet's find thee a livin' one!\n\n"

    @shark_living = SharksAhead::SharkLiving.get_living_sharks
    @shark_living.each.with_index(1) do |shark, i|
      printf "%3s  -  %-50s\n", i, shark[:name]
    end
    description_living
  end

  def description_living
    living_input = nil
    while living_input != "exit"
      give_choices

      living_input = gets.chomp
      the_shark = @shark_living[living_input.to_i-1]

      case living_input
      when /([1-8])/      then puts word_wrap("\n#{the_shark[:description]}\n\n", 75)
      when /^(l|list)$/i  then list_living
      when /^(e|exit)$/i  then goodbye2
      when /^(s|start)$/i then welcome
      else belay_that
      end
    end
  end

  def give_choices
    puts "\nWhat's yer lucky number? Else ye may abandon ship by typin' exit."
    puts "If ye cannot recall the list, type list."
    print "If ye wish to start again, ye may type start. "
  end

  # Word wrap from Ruby Cookbook
  def word_wrap(text, width = 70)
    text.gsub(/(.{1,#{width}})(\s+|\Z)/, "\\1\n")
  end

  def goodbye1
    puts "\nWell then, ye must be a wee babe. I'll sing ye a lullaby instead.\n\n"
    lullaby
    puts "\nCome back to see me when ye get yer mettle up."
    ship_end
    exit
  end

  def goodbye2
    puts "\nFare thee well me matey. Ye may join me crew again anytime!\n\n"
    ship_end
    exit
  end

  def belay_that
    print "\nBelay that! Ye must make a proper choice.  "
  end

  def lullaby
    # Seal Lullaby from The Jungle Book by Rudyard Kipling
    # http://www.poetryloverspage.com/poets/kipling/seal_lullaby.html
    puts <<-DOC
    Oh! hush thee, my baby, the night is behind us,
      And black are the waters that sparkled so green.
    The moon, o'er the combers, looks downward to find us
      At rest in the hollows that rustle between.
    Where billow meets billow, there soft be thy pillow;
      Ah, weary wee flipperling, curl at thy ease!
    The storm shall not wake thee, nor shark overtake thee,
      Asleep in the arms of the slow-swinging seas.
    DOC
  end

  def ship_end
    puts "     .                                             _~        *"
    puts "                       .             *          _~ )_)_~"
    puts "               *                                )_))_))_)"
    puts "    *       .               *       .           _!__!__!_         ."
    puts "                                                \\______t/"
    puts "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\n"
  end
end
